==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/Paste/ts/Paste_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+71"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Indique a dimensão da linha de posicionamento ou insira o ângulo:
Indique a dimensão da linha de posicionamento ou insira o ângulo
Indique a posição [ângulo/comprimento]</translatorcomment>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Co&amp;lar</translatorcomment>
        <translation>Co&amp;lar</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translatorcomment>--exact match--
--file: pt.po--
_Rotação</translatorcomment>
        <translation>Rotação:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Girar entidades colado&lt;br&gt;por este ângulo</translatorcomment>
        <translation>Girar entidades colado&lt;br&gt;por este ângulo</translation>
    </message>
    <message>
        <location line="+90"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ampliar
Escala de tipo de linha global:</translatorcomment>
        <translation>Escala:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Escala entidades colado&lt;br&gt;por este factor</translatorcomment>
        <translation>Escala entidades colado&lt;br&gt;por este factor</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Inverter entidades colada&lt;br&gt;horizontalmente</translatorcomment>
        <translation>Inverter entidades colada&lt;br&gt;horizontalmente</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Inverter entidades colada&lt;br&gt;verticalmente</translatorcomment>
        <translation>Inverter entidades colada&lt;br&gt;verticalmente</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Colar todas as entidades&lt;br&gt;para a camada atual,&lt;br&gt;em vez da camada original</translatorcomment>
        <translation>Colar todas as entidades&lt;br&gt;para a camada atual,&lt;br&gt;em vez da camada original</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Para Camada Atual
Para camada atual
Utilize a camada atual
Colar todas as entidades&lt;br&gt;para a camada atual,&lt;br&gt;em vez da camada original</translatorcomment>
        <translation>Para camada atual</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Substituir camadas&lt;br&gt;existentes no desenho com&lt;br&gt;camadas da área de transferência</translatorcomment>
        <translation>Substituir camadas&lt;br&gt;existentes no desenho com&lt;br&gt;camadas da área de transferência</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Substituir camadas</translatorcomment>
        <translation>Substituir camadas</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Sobrescrever blocos existentes&lt;br&gt;no desenho com blocos&lt;br&gt;da área de transferência</translatorcomment>
        <translation>Sobrescrever blocos existentes&lt;br&gt;no desenho com blocos&lt;br&gt;da área de transferência</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Sobrescrever blocos</translatorcomment>
        <translation>Sobrescrever blocos</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/Paste/ts/Paste_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Indique a dimensão da linha de posicionamento ou insira o ângulo:
Indique a dimensão da linha de posicionamento ou insira o ângulo
Indique a posição [ângulo/comprimento]</translatorcomment>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Co&amp;lar</translatorcomment>
        <translation>Co&amp;le</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translatorcomment>--exact match--
--file: pt.po--
_Rotação</translatorcomment>
        <translation>Rotação:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Girar entidades colado&lt;br&gt;por este ângulo</translatorcomment>
        <translation>Rotacione as entidades coladas&lt;br&gt;por este ângulo</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Ampliar
Escala de tipo de linha global:</translatorcomment>
        <translation>Escala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Escala entidades colado&lt;br&gt;por este factor</translatorcomment>
        <translation>Escalone as entidades coladas&lt;br&gt;por este fator</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Inverter entidades colada&lt;br&gt;horizontalmente</translatorcomment>
        <translation>Inverta as entidades coladas&lt;br&gt;horizontalmente</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Inverter entidades colada&lt;br&gt;verticalmente</translatorcomment>
        <translation>Inverta as entidades coladas&lt;br&gt;verticalmente</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Colar todas as entidades&lt;br&gt;para a camada atual,&lt;br&gt;em vez da camada original</translatorcomment>
        <translation>Cole todas as entidades&lt;br&gt;na camada atual,&lt;br&gt;ao invés da camada original</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Para Camada Atual
Para camada atual
Utilize a camada atual
Colar todas as entidades&lt;br&gt;para a camada atual,&lt;br&gt;em vez da camada original</translatorcomment>
        <translation>Para a camada atual</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Substituir camadas&lt;br&gt;existentes no desenho com&lt;br&gt;camadas da área de transferência</translatorcomment>
        <translation>Substitua as camadas&lt;br&gt;existentes no desenho pelas&lt;br&gt;camadas da área de transferência</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Substituir camadas</translatorcomment>
        <translation>Substitua as camadas</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Sobrescrever blocos existentes&lt;br&gt;no desenho com blocos&lt;br&gt;da área de transferência</translatorcomment>
        <translation>Substitua os Blocos existentes&lt;br&gt;no desenho pelos Blocos&lt;br&gt;da área de transferência</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translatorcomment>--exact match--
--file: InsertBlockItem_pt.ts--
Sobrescrever blocos</translatorcomment>
        <translation>Substitua os Blocos</translation>
    </message>
</context>
</TS>
